Learn R Programming

NormData (version 1.2)

Check.Assum: Check assumptions for a fitted Stage 1 model

Description

Helper function to check the validity of the homoscedasticity and normality assumptions for a fitted Stage 1 model

Usage

Check.Assum(Stage.1.Model)

Value

An object of class Check.Assum with component,

Assume.Homo.S2

Is the homoscedasticity assumption valid?

Assume.Normality.S2

Is the normality assumption valid?

Arguments

Stage.1.Model

The fitted Stage.1 model.

Author

Wim Van der Elst

Details

For details, see Van der Elst (2023).

References

Van der Elst, W. (2024). Regression-based normative data for psychological assessment: A hands-on approach using R. Springer Nature.

See Also

Stage.1

Examples

Run this code
data("Substitution")
# Fit a model with a linear mean prediction function
Fit <- Stage.1(Dataset = Substitution, Model = LDST~Age)
Check.Assum(Fit)
   # Output shows that the homoscedasticity and normality
   # assumptions are both violated

Run the code above in your browser using DataLab